OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bookmarks",
    "No file provided for import" : "No file provided for import",
    "Unsupported file type for import" : "Unsupported file type for import",
    "A Bookmark manager for Nextcloud" : "A Bookmark manager for Nextcloud",
    "Details" : "Details",
    "Rename" : "Rename",
    "Move" : "Move",
    "Delete" : "Delete",
    "New" : "New",
    "New folder" : "New folder",
    "Grid view" : "Grid view",
    "List view" : "List view",
    "Select all" : "Select all",
    "Root folder" : "Root folder",
    "Cancel" : "Cancel",
    "All bookmarks" : "All bookmarks",
    "Recent" : "Recent",
    "Add a bookmark" : "Add a bookmark",
    "Import" : "Import",
    "Export" : "Export",
    "Recently added" : "Recently added",
    "Alphabetically" : "Alphabetically",
    "Most visited" : "Most visited",
    "Last modified" : "Last modified",
    "Bookmarklet" : "Bookmarklet",
    "Clear data" : "Clear data",
    "Delete all bookmarks" : "Delete all bookmarks",
    "Do you really want to delete all your bookmarks?" : "Do you really want to delete all your bookmarks?",
    "Title" : "Title",
    "Link" : "Link",
    "Tags" : "Tags",
    "Attachments" : "Attachments",
    "Notes" : "Notes",
    "Owner" : "Owner",
    "Sharing" : "Sharing",
    "Share link" : "Share link",
    "Copy link" : "Copy link",
    "Allow editing" : "Allow editing",
    "Link copied" : "Link copied",
    "Select" : "Select",
    "Previews" : "Previews",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "Privacy" : "Privacy",
    "This URL is already bookmarked! Overwrite?" : "This URL is already bookmarked! Overwrite?",
    "Folder" : "Folder",
    "Save" : "Save",
    "Bookmarks feed" : "Bookmarks feed"
},
"nplurals=2; plural=(n != 1);");
